@@ -18,7 +18,7 @@ from invenio_records_resources.resources.records.resource import (
     request_search_args,
     request_view_args,
 )
-from invenio_records_resources.resources.records.utils import es_preference
+from invenio_records_resources.resources.records.utils import search_preference
 
 
 #
@@ -44,7 +44,7 @@ class GroupsResource(RecordResource):
         hits = self.service.search(
             identity=g.identity,
             params=resource_requestctx.args,
-            es_preference=es_preference(),
+            search_preference=search_preference(),
         )
         return hits.to_dict(), 200
 
