@@ -9,8 +9,13 @@
 """Groups resource tests."""
 
 
-def test_group_avatar(client, group):
-    res = client.get(f"/groups/{group.id}/avatar.svg")
+def test_group_avatar(app, client, group, user_pub):
+    res = client.get(f"/groups/{group.name}/avatar.svg")
+    assert res.status_code == 403
+
+    user_pub.login(client)
+
+    res = client.get(f"/groups/{group.name}/avatar.svg")
     assert res.status_code == 200
     assert res.mimetype == "image/svg+xml"
     data = res.get_data()
